
setwd("D:/Pro/These/Donnees/WAvsBBA/")

meta=read.table("MetaBBAvsWA.csv",sep=";",h=T)
allser=read.table("AllDaylightEncounters_BBAvsWA_30km_3km_TTR4locs.csv",sep=";",h=T)

library(lme4)
library(nlme)

allser$ReproSp=paste(allser$Species,allser$ReproStage,sep="-")
meta$ReproSp=paste(meta$Species,meta$ReproStage,sep="-")

allser$Act=abs(allser$lagvesact)/3600

# encounters with attendance
seratt=allser[allser$attend==1,]


### These files, obtained from script PrepareDataBBAvsWA, contains only relevant tracks and encounters

##### Trip duration
#plot
boxplot(Duration_d~ReproSp,data=meta,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Trip duration (days)",cex.lab=1.4,cex.axis=1.4)

mdur=lme(Duration_d~ReproStage,random=~1|Bague,data=meta)
plot(mdur)
# very bad residuals

# try a poisson or negbin model
meta$Duration_demih=round(meta$Duration_d*48,0)
mdur=glmer.nb(Duration_demih~ReproSp+(1|Bague),data=meta)
plot(mdur)
# still hard to believe no differences BBA stage

# try model separately BBA stage and species
mdur=lme(Duration_d~Species,random=~1|Bague,data=meta[meta$ReproSp!="BBA-egg",])
mdur=lme(Duration_d~Species,random=~1|Bague,data=meta[meta$ReproSp!="BBA-ch",])
mdur=lme(Duration_d~ReproStage,random=~1|Bague,data=meta[meta$Species=="BBA",])
#residuals not perfect but that will do



#### encounter rates
#largely zero-inflated so we model it in two steps
meta$Enc=ifelse(meta$NbDaylightEnc>0,1,0)
mprobenc=glmer(Enc~Duration_d+ReproSp+AvgNbBat+(1|Bague),data=meta,family="binomial")
mprobenc=glmer(Enc~Duration_d+ReproStage+AvgNbBat+(1|Bague),data=meta[meta$Species=="BBA" & meta$Duration_d>1,],family="binomial")
mprobenc=glmer(Enc~Duration_d+Species+AvgNbBat+(1|Bague),data=meta[meta$ReproSp!="BBA-egg" & meta$Duration_d>1,],family="binomial")
mprobenc=glmer(Enc~Duration_d+Species+AvgNbBat+(1|Bague),data=meta[meta$ReproSp!="BBA-ch" & meta$Duration_d>1,],family="binomial")

meta$ER=meta$NbDaylightEnc/meta$Duration_d
mne=glmer.nb(NbDaylightEncounter~ReproSp+Duration_d+AvgNbBat+(1|Bague),data=meta[meta$ER>0,],nAGQ=0)
mne=glmer.nb(NbDaylightEncounter~ReproStage+Duration_d+AvgNbBat+(1|Bague),data=meta[meta$ER>0 & meta$Species=="BBA",],nAGQ=0)
mne=glmer.nb(NbDaylightEncounter~Species+Duration_d+AvgNbBat+(1|Bague),data=meta[meta$ER>0,],nAGQ=0)
mne=glmer.nb(NbDaylightEncounter~Species+Duration_d+AvgNbBat+(1|Bague),data=meta[meta$ER>0 & meta$ReproSp!="BBA-egg",],nAGQ=0)
mne=glmer.nb(NbDaylightEncounter~Species+Duration_d+AvgNbBat+(1|Bague),data=meta[meta$ER>0 & meta$ReproSp!="BBA-ch",],nAGQ=0)

# mer=lme(ER~ReproSp+AvgNbBat,random=~1|Bague,data=meta[meta$ER>0,])
# mer=lme(ER~ReproStage+AvgNbBat,random=~1|Bague,data=meta[meta$ER>0 & meta$Species=="BBA",])
# mer=lme(ER~Species+AvgNbBat,random=~1|Bague,data=meta[meta$ER>0,])

#plot
#boxplot(ER~ReproSp,data=meta,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Number of encounters per day at sea",cex.lab=1.4,cex.axis=1.4)
boxplot(NbDaylightEncounter~ReproSp,data=meta,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Number of encounters per trip",cex.lab=1.4,cex.axis=1.4)


#### probability to attend at an encounter
mprobatt=glmer(attend~ReproSp+avg_nbbatrangedet+(1|TripID)+(1|Bague),data=allser,family="binomial")
mprobatt2=glmer(attend~Species*avg_nbbatrangedet+(1|TripID)+(1|Bague),data=allser,family="binomial")

#plot
proba=c(sum(allser$attend[allser$ReproSp=="BBA-ch"])/sum(allser$ReproSp=="BBA-ch"),sum(allser$attend[allser$ReproSp=="BBA-egg"])/sum(allser$ReproSp=="BBA-egg"),sum(allser$attend[allser$ReproSp=="WA-egg"])/sum(allser$ReproSp=="WA-egg"))
np=c(sum(allser$ReproSp=="BBA-ch"),sum(allser$ReproSp=="BBA-egg"),sum(allser$ReproSp=="WA-egg"))

barplot(proba,names.arg=c("BBA chick", "BBA egg", "WA egg"),space=c(0.2,0.2,0.8),ylim=c(0,1),col=c("grey80","grey60","grey25"),border="black",ylab="Proportion of encounters followed by attendance",cex.lab=1.4,cex.axis=1.2,font.axis=2,cex.names=1.4)
text(c(0.7,1.9,3.7),y=proba+0.05,paste("n = ",np,sep=""),cex=1.2)


#### duration encounter with attendance
mdurencatt=glmer(durser~ReproSp+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague),data=seratt,family="poisson")
mdurencatt2=glmer(durser~Species*propact+avg_nbbatrangedet+(1|TripID)+(1|Bague),data=seratt,family="poisson")

#plot
boxplot(durser/4~ReproSp,data=seratt,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Duration of encounter with attendance (h)",cex.lab=1.4,cex.axis=1.4)


#### proportion encounter spent attending
mpropencatt=glmer(dur_attend~Species*propact+avg_nbbatrangedet+(1|TripID)+(1|Bague)+offset(log(durser)),data=seratt,family="poisson")
mpropencatt2=glmer(dur_attend~ReproSp+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague)+offset(log(durser)),data=seratt,family="poisson")
mpropencatt2=glmer(dur_attend~ReproStage+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague)+offset(log(durser)),data=seratt[seratt$Species=="BBA",],family="poisson")
mpropencatt2=glmer(dur_attend~Species+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague)+offset(log(durser)),data=seratt[seratt$ReproSp!="BBA-egg",],family="poisson")
mpropencatt2=glmer(dur_attend~Species+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague)+offset(log(durser)),data=seratt[seratt$ReproSp!="BBA-ch",],family="poisson")

#plot
boxplot((dur_attend/durser)~ReproSp,data=seratt,ylim=c(0,1),col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Proportion of the encounter spent attending boat",cex.lab=1.4,cex.axis=1.4)


#### Average distance when attending
mdistatt=lme(avgdist_attend~ReproSp+avg_nbbatrangedet+propact,random=~1|TripID,data=seratt)
mdistatt2=lme(avgdist_attend~Species*propact+avg_nbbatrangedet,random=~1|TripID,data=seratt)

#plot
boxplot(avgdist_attend~ReproSp,data=seratt,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Distance from boat when attending (m)",cex.lab=1.4,cex.axis=1.4)

# just to check adding Bague as random factor doesn't change stats (lmer no p-values)
mdistatt=lmer(avgdist_attend~ReproSp+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague),data=seratt)



#### Duration encounter when no attendance
mdurencna=glmer(durser~ReproSp+avg_nbbatrangedet+propact+(1|TripID)+(1|Bague),data=allser[allser$attend==0,],family="poisson")

#plot
par(mar=c(4,7,3,4))
boxplot(durser/4~ReproSp,data=allser[allser$attend==0,],col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab=paste("Duration of encounter","\n", "when no attendance (h)",sep=""),cex.lab=2,cex.axis=2,font.lab=2)


#### Bathymetry
# see script dedicated to that: BathyAnalysesWAvsBBA.R



### Figure 3
par(mfrow=c(1,2),cex.lab=1.2,cex.axis=1.2,font.lab=2,font.axis=2,mar=c(4,7,3,3))
boxplot(Duration_d~ReproSp,data=meta,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Trip duration (days)",cex.lab=1.4,cex.axis=1.4)
boxplot(NbDaylightEncounter~ReproSp,data=meta,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Number of encounters per trip",cex.lab=1.4,cex.axis=1.4)

### Figure 4
par(mfrow=c(2,2),cex.lab=1.2,cex.axis=1.2,font.lab=2,font.axis=2,mar=c(4,7,3,3))
proba=c(sum(allser$attend[allser$ReproSp=="BBA-ch"])/sum(allser$ReproSp=="BBA-ch"),sum(allser$attend[allser$ReproSp=="BBA-egg"])/sum(allser$ReproSp=="BBA-egg"),sum(allser$attend[allser$ReproSp=="WA-egg"])/sum(allser$ReproSp=="WA-egg"))
np=c(sum(allser$ReproSp=="BBA-ch"),sum(allser$ReproSp=="BBA-egg"),sum(allser$ReproSp=="WA-egg"))

barplot(proba,names.arg=c("BBA chick", "BBA egg", "WA egg"),space=c(0.2,0.2,0.8),ylim=c(0,1),col=c("grey80","grey60","grey25"),border="black",ylab=paste("Proportion of encounters","\n", "followed by attendance",sep=""),cex.lab=1.4,cex.axis=1.2,font.axis=2,cex.names=1.4)
text(c(0.7,1.9,3.7),y=proba+0.05,paste("n = ",np,sep=""),cex=1.2)

boxplot(durser/4~ReproSp,data=seratt,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Duration of encounter with attendance (h)",cex.lab=1.4,cex.axis=1.4)

boxplot((dur_attend/durser)~ReproSp,data=seratt,ylim=c(0,1),col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab=paste("Proportion of the encounter","\n","spent attending boat",sep=""),cex.lab=1.4,cex.axis=1.4)

boxplot(avgdist_attend~ReproSp,data=seratt,col=c("grey80","grey60","grey25"),names=c("BBA chick", "BBA egg", "WA egg"),ylab="Distance from boat when attending (m)",cex.lab=1.4,cex.axis=1.4)






