

#### Analyses bathymetry with or without boats

library(geosphere)
library(marmap)

kermap=getNOAA.bathy(59,80,-44,-54,resolution=2)
cromap=getNOAA.bathy(45,58,-40,-50,resolution=2)


######## BBA
alltr=read.table("D:/Pro/These/Donnees/WAvsBBA/BBA/AllBirds14minAllBoats10min.csv",sep=";",h=T)
bi=alltr[alltr$track_status=="long_track",]

### We assign an index for all boats of the study, so to retrieve coresponding columns
nbvessels=7
disttoves=c()
for (i in 1:nbvessels){
  disttoves=c(disttoves,paste("DistToVes10_",i,sep=""))
}

#extract and combine bird date and time
birdtime=as.POSIXct(apply(cbind(as.character(bi$Date),as.character(bi$Time)),1,function(X){
  Date=unlist(strsplit(as.character(X[1]),"/"))
  Time=as.character(X[2])
  out=paste(paste(as.character(Date[3]),as.character(Date[2]),as.character(Date[1]), sep='-'),Time, sep=' ')
  return(out)
}),tz='GMT')

#bi$Loc=seq(1,dim(bi)[1])
attrac.threshold=30   # we define attraction area as a 30km circle aound boats
sitting.threshold=10/3.6   # we consider locations with speed<10km/h to be sitting on water
attend.threshold=3   # birds sitting within 3km of vessels will be considered attending boats

bi$Speed_ms=c(distCosine(cbind(bi$Longitude,bi$Latitude)[-dim(bi)[1],],cbind(bi$Longitude,bi$Latitude)[-1,])/as.double(-difftime(birdtime[-dim(bi)[1]],birdtime[-1],units="secs")),NA)
bi$Heading=as.double(c(bearing(cbind(bi$Longitude,bi$Latitude)[-dim(bi)[1],],cbind(bi$Longitude,bi$Latitude)[-1,]),NA))%%360

coldist=which(names(bi)%in%disttoves)
bi$ClosestVes=apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<nbvessels,which.min(as.double(X[coldist])),NA)})
bi$MinDistVes=as.double(apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<nbvessels,min(as.double(X[coldist]),na.rm=T),NA)}))

bi$SitOnWater=ifelse(bi$Speed_ms<=sitting.threshold,"sit","fly")
bi$AttendBoat=ifelse(bi$SitOnWater=="sit" & bi$MinDistVes<attend.threshold,1,0)

sunelev=tripEstimation::elevation(bi$Longitude,bi$Latitude,tripEstimation::solar(birdtime))
bi$DayNight=ifelse(sunelev>(-6),"day","night")


bi$bathy=get.depth(kermap,bi$Longitude,bi$Latitude,locator=F)[,3]

bibba=bi



##### WA
### WA 11
bifol="D:/Pro/These/Donnees/WAAL/BirdsToVessels/2011/"
bifi=list.files(bifol)
bi=c()
for(fi in bifi){
  tr=read.table(paste(bifol,fi,sep=""),sep=";",h=T)
  bi=rbind(bi,cbind(tr,rep(fi,dim(tr)[1])))
}

### We assign an index for all boats of the study, so to retrieve coresponding columns
vessels=c(1,2,3,5,6,7,88)
disttoves=c()
for (i in 1:length(vessels)){
  disttoves=c(disttoves,paste("distVessel",vessels[i],sep=""))
}

#extract and combine bird date and time
birdtime=as.POSIXct(apply(cbind(as.character(bi$Date),as.character(bi$Time)),1,function(X){
  Date=unlist(strsplit(as.character(X[1]),"/"))
  Time=as.character(X[2])
  out=paste(paste(as.character(Date[3]),as.character(Date[2]),as.character(Date[1]), sep='-'),Time, sep=' ')
  return(out)
}),tz='GMT')

coldist=which(names(bi)%in%disttoves)
bi$ClosestVes=apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<length(vessels),which.min(as.double(X[coldist])),NA)})
bi$MinDistVes=as.double(apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<length(vessels),min(as.double(X[coldist]),na.rm=T),NA)}))/1000

bi$AroundShelf=ifelse(bi$Longitude<55.5 & bi$Longitude>45.5 & bi$Latitude<(-41.5) & bi$Latitude>(-48.5),1,0)
bi$bathy[bi$AroundShelf==1]=get.depth(cromap,bi$Longitude[bi$AroundShelf==1],bi$Latitude[bi$AroundShelf==1],locator=F)[,3]

bi11=bi
names(bi11)[33]="filename"

### WA 12
bifol="D:/Pro/These/Donnees/WAAL/BirdsToVessels/2012/"
bifi=list.files(bifol)
bi=c()
for(fi in bifi){
  tr=read.table(paste(bifol,fi,sep=""),sep=";",h=T)
  bi=rbind(bi,cbind(tr,rep(fi,dim(tr)[1])))
}

### We assign an index for all boats of the study, so to retrieve coresponding columns
vessels=c(1,2,3,5,6,7,88)
disttoves=c()
for (i in 1:length(vessels)){
  disttoves=c(disttoves,paste("distVessel",vessels[i],sep=""))
}

#extract and combine bird date and time
birdtime=as.POSIXct(apply(cbind(as.character(bi$Date),as.character(bi$Time)),1,function(X){
  Date=unlist(strsplit(as.character(X[1]),"/"))
  Time=as.character(X[2])
  out=paste(paste(as.character(Date[3]),as.character(Date[2]),as.character(Date[1]), sep='-'),Time, sep=' ')
  return(out)
}),tz='GMT')

coldist=which(names(bi)%in%disttoves)
bi$ClosestVes=apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<length(vessels),which.min(as.double(X[coldist])),NA)})
bi$MinDistVes=as.double(apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<length(vessels),min(as.double(X[coldist]),na.rm=T),NA)}))/1000

bi$AroundShelf=ifelse(bi$Longitude<55.5 & bi$Longitude>45.5 & bi$Latitude<(-41.5) & bi$Latitude>(-48.5),1,0)
bi$bathy[bi$AroundShelf==1]=get.depth(cromap,bi$Longitude[bi$AroundShelf==1],bi$Latitude[bi$AroundShelf==1],locator=F)[,3]

names(bi)[32]="filename"


#### Analyses through track-level means or proportions
library(nlme)
library(plyr)

bbadistcol=120

bbadepthnatsit=ddply(bibba[bibba$MinDistVes>30 & bibba$SitOnWater=="sit" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol,],~TripID,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
bbadepthnatfly=ddply(bibba[bibba$MinDistVes>30 & bibba$SitOnWater=="fly" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol,],~TripID,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
bbadepthboat=ddply(bibba[bibba$MinDistVes<=3 & bibba$SitOnWater=="sit" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol,],~TripID,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
boxplot(bbadepthnatsit[,2],bbadepthnatfly[,2],bbadepthboat[,2])
boxplot(bbadepthnatsit[,3],bbadepthnatfly[,3],bbadepthboat[,3])

wa11depthnatsit=ddply(bi11[bi11$AroundShelf==1 & bi11$MinDistVes>30 & bi11$SitWater=="pose" & bi11$jour=="jour",],~filename,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
wa11depthnatfly=ddply(bi11[bi11$AroundShelf==1 & bi11$MinDistVes>30 & bi11$SitWater=="vol" & bi11$jour=="jour",],~filename,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
wa11depthboat=ddply(bi11[bi11$AroundShelf==1 & bi11$MinDistVes<=3 & bi11$SitWater=="pose" & bi11$jour=="jour",],~filename,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})

wa12depthnatsit=ddply(bi[bi$AroundShelf==1 & bi$MinDistVes>30 & bi$SitWater=="pose" & bi$jour=="jour",],~filename,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
wa12depthnatfly=ddply(bi[bi$AroundShelf==1 & bi$MinDistVes>30 & bi$SitWater=="vol" & bi$jour=="jour",],~filename,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})
wa12depthboat=ddply(bi[bi$AroundShelf==1 & bi$MinDistVes<=3 & bi$SitWater=="pose" & bi$jour=="jour",],~filename,function(X){c(mean(X$bathy,na.rm=T),sum(X$bathy> -1400 & X$bathy< -600,na.rm=T)/length(X$bathy))})

wadepthnatsit=rbind(wa11depthnatsit,wa12depthnatsit)
wadepthnatfly=rbind(wa11depthnatfly,wa12depthnatfly)
wadepthboat=rbind(wa11depthboat,wa12depthboat)
boxplot(wadepthnatsit[,2],wadepthnatfly[,2],wadepthboat[,2])
boxplot(wadepthnatsit[,3],wadepthnatfly[,3],wadepthboat[,3])

names(wadepthnatsit)=c("track","meandepth","propslope")
names(wadepthnatfly)=c("track","meandepth","propslope")
names(wadepthboat)=c("track","meandepth","propslope")
names(bbadepthnatsit)=c("track","meandepth","propslope")
names(bbadepthnatfly)=c("track","meandepth","propslope")
names(bbadepthboat)=c("track","meandepth","propslope")

dpi=rbind(bbadepthnatsit,bbadepthnatfly,bbadepthboat,wadepthnatsit,wadepthnatfly,wadepthboat)
dpi$sp=c(rep("BBA",dim(bbadepthnatsit)[1]+dim(bbadepthnatfly)[1]+dim(bbadepthboat)[1]),rep("WA",dim(wadepthnatsit)[1]+dim(wadepthnatfly)[1]+dim(wadepthboat)[1]))
dpi$boat=c(rep(0,dim(bbadepthnatsit)[1]+dim(bbadepthnatfly)[1]),rep(1,dim(bbadepthboat)[1]),rep(0,dim(wadepthnatsit)[1]+dim(wadepthnatfly)[1]),rep(1,dim(wadepthboat)[1]))
dpi$SitOnWater=c(rep("sit",dim(bbadepthnatsit)[1]),rep("fly",dim(bbadepthnatfly)[1]),rep("sit",dim(bbadepthboat)[1]+dim(wadepthnatsit)[1]),rep("fly",dim(wadepthnatfly)[1]),rep("sit",dim(wadepthboat)[1]))
dpi=dpi[is.na(dpi$meandepth)==F,]

mdepth=lme(meandepth~SitOnWater*sp,random=~1|track,data=dpi[dpi$boat==0,])
mps=lme(propslope~SitOnWater*sp,random=~1|track,data=dpi[dpi$boat==0,])


####### nice clean figures
### Proportion of time spent on shelf-slope waters
par(mar=c(4,7,3,2))
boxplot(bbadepthnatsit[,3]*100,bbadepthnatfly[,3]*100,wadepthnatsit[,3]*100,wadepthnatfly[,3]*100,col=c("grey70","grey70","grey25","grey25"),names=c("sitting BBA", "flying BBA", "sitting WA","flying WA"),ylab=paste("% time spent on shelf-slope waters","\n","when far from boats",sep=""),cex.lab=1.8,cex.axis=1.8)


### general histograms depth used
#par(mfrow=c(2,2))
par(mar=c(5,5,3,2),mfrow=c(2,2))
hist(bibba$bathy[bibba$MinDistVes>30 & bibba$SitOnWater=="sit" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol],xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=23,xlab="Bathymetry",main="",col="grey70",cex.axis=1.5,cex.lab=1.6,font=2,font.lab=2)
text(-2000,0.00195,"BBA - daylight sitting",font=2,cex=1.6)
hist(c(bi$bathy[bi$AroundShelf==1 & bi$MinDistVes>30 & bi$SitWater=="pose" & bi$jour=="jour"],bi11$bathy[bi11$AroundShelf==1 & bi11$MinDistVes>30 & bi11$SitWater=="pose" & bi11$jour=="jour"]),xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=23,xlab="Bathymetry",main="",col="grey25",cex.axis=1.5,cex.lab=1.6,font=2,font.lab=2)
text(-2000,0.00195,"WA - daylight sitting",font=2,cex=1.6)
hist(bibba$bathy[bibba$MinDistVes<=3 & bibba$SitOnWater=="sit" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol],xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=12,xlab="Bathymetry",main="",col="grey70",cex.axis=1.5,cex.lab=1.6,font=2,font.lab=2)
text(-2000,0.00195,"BBA - daylight attendance",font=2,cex=1.6)
hist(c(bi$bathy[bi$AroundShelf==1 & bi$MinDistVes<=3 & bi$SitWater=="pose" & bi$jour=="jour"],bi11$bathy[bi11$AroundShelf==1 & bi11$MinDistVes<=3 & bi11$SitWater=="pose" & bi11$jour=="jour"]),xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=12,xlab="Bathymetry",main="",col="grey25",cex.axis=1.5,cex.lab=1.6,font=2,font.lab=2)
text(-2000,0.00195,"WA - daylight attendance",font=2,cex=1.6)


hist(bibba$bathy[bibba$MinDistVes>30 & bibba$SitOnWater=="sit" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol],xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=23,xlab="Bathymetry",main=paste("BBA - daylight sitting >30km from boats","\n","(>",bbadistcol,"km from colony)",sep=""),col="grey70",cex.axis=1.5,cex.lab=1.5)
hist(c(bi$bathy[bi$AroundShelf==1 & bi$MinDistVes>30 & bi$SitWater=="pose" & bi$jour=="jour"],bi11$bathy[bi11$AroundShelf==1 & bi11$MinDistVes>30 & bi11$SitWater=="pose" & bi11$jour=="jour"]),xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=23,xlab="Bathymetry",main="WA - daylight sitting >30km from boat",col="grey25",cex.axis=1.5,cex.lab=1.5)
hist(bibba$bathy[bibba$MinDistVes<=3 & bibba$SitOnWater=="sit" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol],xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=12,xlab="Bathymetry",main=paste("BBA - daylight attendance","\n","(>",bbadistcol,"km from colony)",sep=""),col="grey70",cex.axis=1.5,cex.lab=1.5)
hist(c(bi$bathy[bi$AroundShelf==1 & bi$MinDistVes<=3 & bi$SitWater=="pose" & bi$jour=="jour"],bi11$bathy[bi11$AroundShelf==1 & bi11$MinDistVes<=3 & bi11$SitWater=="pose" & bi11$jour=="jour"]),xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=12,xlab="Bathymetry",main="WA - daylight attendance",col="grey25",cex.axis=1.5,cex.lab=1.5)

hist(bibba$bathy[bibba$MinDistVes>30 & bibba$SitOnWater=="fly" & bibba$DayNight=="day" & bibba$distance_to_colony>bbadistcol],xlim=c(-4400,200),ylim=c(0,0.002),freq=F,breaks=23,xlab="Bathymetry",main=paste("BBA - daylight flying >30km from boats","\n","(>",bbadistcol,"km from colony)",sep=""),col="grey70",cex.axis=1.5,cex.lab=1.5)































### Analyses
trips=unique(bi$TripID)

birdid=c()

propsittingfar=c()
propflyingfar=c()
propsittingclose=c()
for (i in 1:length(trips)){
  tr=bi[as.character(bi$TripID)==as.character(trips[i]),]
  
  birdid=c(birdid,as.character(tr$BirdID[1]))
  
  propsittingfar=c(propsittingfar,sum(tr$bathy[tr$DayNight=="day" & tr$SitOnWater=="sit" & tr$MinDistVes>30 & tr$distance_to_colony>80]<(-600) & tr$bathy[tr$DayNight=="day" & tr$SitOnWater=="sit" & tr$MinDistVes>30 & tr$distance_to_colony>80]>(-1400))/dim(tr[tr$DayNight=="day" & tr$SitOnWater=="sit" & tr$MinDistVes>30 & tr$distance_to_colony>80,])[1])
  propflyingfar=c(propflyingfar,sum(tr$bathy[tr$DayNight=="day" & tr$SitOnWater=="fly" & tr$MinDistVes>30 & tr$distance_to_colony>80]<(-600) & tr$bathy[tr$DayNight=="day" & tr$SitOnWater=="fly" & tr$MinDistVes>30 & tr$distance_to_colony>80]>(-1400))/dim(tr[tr$DayNight=="day" & tr$SitOnWater=="fly" & tr$MinDistVes>30 & tr$distance_to_colony>80,])[1])
  propsittingclose=c(propsittingclose,sum(tr$bathy[tr$DayNight=="day" & tr$SitOnWater=="sit" & tr$MinDistVes<3 & tr$distance_to_colony>80]<(-600) & tr$bathy[tr$DayNight=="day" & tr$SitOnWater=="sit" & tr$MinDistVes<3 & tr$distance_to_colony>80]>(-1400))/dim(tr[tr$DayNight=="day" & tr$SitOnWater=="sit" & tr$MinDistVes<3 & tr$distance_to_colony>80,])[1])
  
  
}

boxplot(propsittingfar,propsittingclose,propflyingfar)
library(lme4)
resp=c(propsittingfar,propflyingfar)
rand=c(birdid,birdid)
expl=c(rep("sit",length(trips)),rep("fly",length(trips)))
m=glmer(resp~expl+(1|rand))

