
library(geosphere)
library(marmap)


### load big map western Indian Ocean
load("D:/Pro/These/Donnees/BathyMapWestIndianOcean.RData")

### get maps for the manuscript BBA vs WA
kermap=getNOAA.bathy(59,80,-44,-54,resolution=2)
cromap=getNOAA.bathy(45,58,-40,-50,resolution=2)

### Palette for the maps
land.pal <- colorRampPalette( c("#467832", "#887438", "#B19D48", "#DBC758", "#FAE769",
                                "#FAEB7E", "#FCED93", "#FCF1A7", "#FCF6C1", "#FDFAE0"))

zbreaks2 <- seq(0, 500, by=20)
greys <-c(land.pal(sum(zbreaks2>=0)-1))

#blues=c('lightsteelblue4','lightsteelblue3','lightsteelblue1')
blues = c("royalblue4","lightsteelblue4","lightsteelblue1")








###### WA
setwd('D:/Pro/WA-Fisheries_AnalysesData2011-12-13/BirdsToVessels/')

### plot crozet map
plot(cromap,xlim=c(48,53.5),ylim=c(-47,-45),image=T,land=T,shallowest.isobath=+2000,deepest.isobath=-6000,step=2000,drawlabel=T,bpal=list(c(0,max(cromap),greys),c(min(cromap),0,blues)),cex.axis=1.5,cex.lab=1.5)
#xlim=c(48,53.5),ylim=c(-47.2,-44.5),

### add tracks
i=0
colortracks=heat.colors(72)[order(runif(72,0,1))]
#2011
fichiers=list.files("2011/")
for (fi in fichiers){
  i=i+1
  tr=read.table(paste("2011/",fi,sep=""),sep=";",h=T)
  coltr=colortracks[i]
  
  #distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)]),na.rm=T)/1000})
  
  points(tr$Longitude,tr$Latitude,type="l",lwd=1,col=coltr)
}

#2012
fichiers=list.files("2012/")
for (fi in fichiers){
  i=i+1
  tr=read.table(paste("2012/",fi,sep=""),sep=";",h=T)
  coltr=colortracks[i]
  
  #distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)-1]),na.rm=T)/1000})
  
  points(tr$Longitude,tr$Latitude,type="l",lwd=1,col=coltr)
}

### add attendance behaviour
#2011
fichiers=list.files("2011/")
for (fi in fichiers){
  tr=read.table(paste("2011/",fi,sep=""),sep=";",h=T)
  
  distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)]),na.rm=T)/1000})
  
  points(tr$Longitude[distves<3 & tr$SitWater=="pose"],tr$Latitude[distves<3 & tr$SitWater=="pose"],pch=21,cex=1.5,col="dark orange",bg="orange")#col="#008B45",bg="#00EE76"
}
#2012
fichiers=list.files("2012/")
for (fi in fichiers){
  tr=read.table(paste("2012/",fi,sep=""),sep=";",h=T)
  
  distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)-1]),na.rm=T)/1000})
  
  points(tr$Longitude[distves<3 & tr$SitWater=="pose"],tr$Latitude[distves<3 & tr$SitWater=="pose"],pch=21,cex=1.5,col="dark orange",bg="orange")#col="#008B45",bg="#00EE76"
}


###### BBA
setwd("D:/Pro/These/Donnees/BBA/BBA2011ToVessels/")
library(geosphere)

### Select BBA tracks
alltr=read.table("D:/Pro/These/Donnees/WAvsBBA/BBA/AllBirds14minAllBoats10min.csv",sep=";",h=T)
bi=alltr[alltr$track_status=="long_track",]
setwd("D:/Pro/These/Donnees/WAvsBBA/")
metabba=read.table("BBA/MetaBBAToVessels.csv",sep=";",h=T)
metabbafilt=metabba[is.na(metabba$ReproStat)==F & metabba$duration>12 & metabba$maxgap/60/metabba$duration<0.05 & metabba$nbloc>300,]
bi=bi[which(bi$TripID%in%unique(metabbafilt$TripID)),]

nbvessels=7
disttoves=c()
for (i in 1:nbvessels){
  disttoves=c(disttoves,paste("DistToVes10_",i,sep=""))
}

#extract and combine bird date and time
birdtime=as.POSIXct(apply(cbind(as.character(bi$Date),as.character(bi$Time)),1,function(X){
  Date=unlist(strsplit(as.character(X[1]),"/"))
  Time=as.character(X[2])
  out=paste(paste(as.character(Date[3]),as.character(Date[2]),as.character(Date[1]), sep='-'),Time, sep=' ')
  return(out)
}),tz='GMT')

attrac.threshold=30   # we define attraction area as a 30km circle aound boats
sitting.threshold=10/3.6   # we consider locations with speed<10km/h to be sitting on water
attend.threshold=3   # birds sitting within 3km of vessels will be considered attending boats

bi$Speed_ms=c(distCosine(cbind(bi$Longitude,bi$Latitude)[-dim(bi)[1],],cbind(bi$Longitude,bi$Latitude)[-1,])/as.double(-difftime(birdtime[-dim(bi)[1]],birdtime[-1],units="secs")),NA)

coldist=which(names(bi)%in%disttoves)
bi$MinDistVes=as.double(apply(bi,1,function(X){ifelse(sum(is.na(X[coldist]))<nbvessels,min(as.double(X[coldist]),na.rm=T),NA)}))

bi$SitOnWater=ifelse(bi$Speed_ms<=sitting.threshold,"sit","fly")
bi$AttendBoat=ifelse(bi$SitOnWater=="sit" & bi$MinDistVes<attend.threshold,1,0)


### map of kerguelen
plot(kermap,xlim=c(65,80),ylim=c(-52,-46),image=T,land=T,shallowest.isobath=+2000,deepest.isobath=-6000,step=2000,drawlabel=T,bpal=list(c(0,max(kermap),greys),c(min(kermap),0,blues)),cex.axis=1.5,cex.lab=1.5)

### Add BBA tracks to map
colortracks=heat.colors(10)[order(runif(190,0,1))]
i=0
for (t in unique(bi$TripID)[c(1,5,35,48,56,80,102,147,185,10)]){
  tr=bi[bi$TripID==t,]
  
  i=i+1
  coltr=colortracks[i]
  
  points(tr$Longitude,tr$Latitude,type="l",lwd=1,col=coltr)
}

### Add BBA attendance to map
for (t in unique(bi$TripID)){
  tr=bi[bi$TripID==t,]
  
  points(tr$Longitude[tr$AttendBoat==1],tr$Latitude[tr$AttendBoat==1],pch=21,cex=1.5,col="#008B45",bg="#00EE76")
}






#### The same for a general map of the area
png(filename=paste("D:/Pro/These/Resultats/BBAvsWA/","BigMap.png",sep=""),width=1680,height=1200)
par(mar=c(7,7,4,3))

dev.off()

plot(studyareabig,image=T,land=T,shallowest.isobath=+8000,deepest.isobath=-6000,step=200000,drawlabel=F,bpal=list(c(0,max(studyareabig),greys),c(min(studyareabig),0,blues)),cex.axis=2.5,cex.lab=2.5,lty=0)

### WA
setwd('D:/Pro/WA-Fisheries_AnalysesData2011-12-13/BirdsToVessels/')

### add tracks
i=0
colortracks=heat.colors(72)[order(runif(72,0,1))]
colortracks=rep("orange",72)
#2011
fichiers=list.files("2011/")
for (fi in fichiers){
  i=i+1
  tr=read.table(paste("2011/",fi,sep=""),sep=";",h=T)
  coltr=colortracks[i]
  
  #distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)]),na.rm=T)/1000})
  
  points(tr$Longitude,tr$Latitude,type="l",lwd=2,col=coltr)
}

#2012
fichiers=list.files("2012/")
for (fi in fichiers){
  i=i+1
  tr=read.table(paste("2012/",fi,sep=""),sep=";",h=T)
  coltr=colortracks[i]
  
  #distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)-1]),na.rm=T)/1000})
  
  points(tr$Longitude,tr$Latitude,type="l",lwd=2,col=coltr)
}

### add attendance behaviour
#2011
fichiers=list.files("2011/")
for (fi in fichiers){
  tr=read.table(paste("2011/",fi,sep=""),sep=";",h=T)
  
  distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)]),na.rm=T)/1000})
  
  points(tr$Longitude[distves<3 & tr$SitWater=="pose"],tr$Latitude[distves<3 & tr$SitWater=="pose"],pch=21,cex=1.5,col="#008B45",bg="#00EE76")
}
#2012
fichiers=list.files("2012/")
for (fi in fichiers){
  tr=read.table(paste("2012/",fi,sep=""),sep=";",h=T)
  
  distves=apply(tr,1,function(X){min(as.double(X[c(12,15,18,21,24,27,30)]),na.rm=T)/1000})
  
  points(tr$Longitude[distves<3 & tr$SitWater=="pose"],tr$Latitude[distves<3 & tr$SitWater=="pose"],pch=21,cex=1.5,col="#008B45",bg="#00EE76")
}



### BBA
setwd("D:/Pro/These/Donnees/BBA/BBA2011ToVessels/")

colortracks=rep("red",190)
i=0
for (t in unique(bi$TripID)){
  tr=bi[bi$TripID==t,]
  
  i=i+1
  coltr=colortracks[i]
  
  points(tr$Longitude,tr$Latitude,type="l",lwd=2,col=coltr)
}

### Add BBA attendance to map
for (t in unique(bi$TripID)){
  tr=bi[bi$TripID==t,]
  
  points(tr$Longitude[tr$AttendBoat==1],tr$Latitude[tr$AttendBoat==1],pch=21,cex=1.5,col="#008B45",bg="#00EE76")
}





