
##### Prepare data for a BBA vs WA comparison
##### Starts from files listing all locs within 30km, per sp
##### Together with metadata without Attendance info
##### Defines encounters following a common definition
##### Extract relevant metrics of boat interactions, at track and encounter levels
##### Stores results in one track-metadata and one encounter-metadata file combining both species

library(geosphere)
library(marmap)

setwd("D:/Pro/These/Donnees/WAvsBBA/")

foldWA="WA/"
foldBBA="BBA/"

##### Attrac and attend locs
attrac.threshold=30   # we define attraction area as a 30km circle aound boats
sitting.threshold=10/3.6   # we consider locations with speed<10km/h to be sitting on water
attend.threshold=3   # birds sitting within 3km of vessels will be considered attending boats
timetoreturn=4 # if more than X consecutive locs away from attraction range => new encounter

##### WA initial metadata
metawa=read.table("WA/MetaDataForAnalysisInCrozet.csv",sep=";",h=T)
metawa=metawa[metawa$Year!="2013",] # keep 2011 and 2012
nwa=dim(metawa)[1]

mwa=data.frame("Species"=rep("WA",nwa),"Year"=as.character(metawa$Year),"BirdID"=as.character(metawa$BirdID),"TripID"=as.character(metawa$TripID),"File"=as.character(metawa$Filename),"Bague"=as.character(metawa$Bague),"ReproStage"=rep("egg",nwa),"Sex"=as.character(metawa$Sexe),"Age"=metawa$Age,"MaxRange_km"=metawa$MaxRange,"TotDist_km"=metawa$TotDist,"Duration_d"=metawa$Duration,"AvgNbBat"=metawa$avg_nbbat)


##### BBA initial metadata
metabba=read.table("BBA/MetaBBAToVessels.csv",sep=";",h=T)

# exclude very short tracks and those whose reproductive status was unknown
removetrips=as.character(metabba$TripID[is.na(metabba$ReproStat)==T | metabba$duration<12 | metabba$maxgap/60/metabba$duration>0.05 | metabba$nbloc<300])
metabba=metabba[is.na(metabba$ReproStat)==F & metabba$duration>12 & metabba$maxgap/60/metabba$duration<0.05 & metabba$nbloc>300,]
   
nbba=dim(metabba)[1]

mbba=data.frame("Species"=rep("BBA",nbba),"Year"=rep("2012",nbba),"BirdID"=as.character(metabba$BirdID),"TripID"=as.character(metabba$TripID),"File"=rep(NA,nbba),"Bague"=as.character(metabba$Bague),"ReproStage"=as.character(metabba$ReproStat),"Sex"=as.character(metabba$sex),"Age"=rep(NA,nbba),"MaxRange_km"=metabba$maxrange,"TotDist_km"=rep(NA,nbba),"Duration_d"=metabba$duration/24,"AvgNbBat"=metabba$AvgNbBat350km)



##### WA attraction locs and encounter series
### We use 
setwd("D:/Pro/These/Donnees/WAAL/BirdsToVessels/")
allattrlocwa=read.table(paste("Test/","AllAttrLoc_",attrac.threshold,"km_",attend.threshold,"km_","TTR",timetoreturn,"locs.csv",sep=""),sep=";",h=T)

aatlwa=allattrlocwa[allattrlocwa$Year!="2013",]

allserwa=read.table(paste("Test/DetectionSeries_",attrac.threshold,"km_",attend.threshold,"km_","TTR",timetoreturn,"locs.csv",sep=""),sep=";",h=T)
names(allserwa)[13]="daystart"
allserwa$daystart=ifelse(allserwa$daystart=="jour","day","night")
# we remove 2013, and keep only encounters starting at day, containing flight during day
# we also discard encounters of transiting boats as this rarely happens with BBA
aswa=allserwa[allserwa$Year!="2013" & allserwa$daystart=="day" & allserwa$dayflight==1 & abs(allserwa$lagvesact)<3600,]
aswa$ReproStage=rep("egg",dim(aswa)[1])
aswa$Species=rep("WA",dim(aswa)[1])

#### BBA attraction locs and encounter series
setwd("D:/Pro/These/Donnees/BBA/BBA2011ToVessels/")

allattrlocbba=read.table(paste("BBA14minBoat10min_","AllAttrLoc_",attrac.threshold,"km_",attend.threshold,"km_","TTR",timetoreturn,"locs.csv",sep=""),sep=";",h=T)

allserbba=read.table(paste("BBA14minBoat10min_","DetectionSeries_",attrac.threshold,"km_",attend.threshold,"km_","TTR",timetoreturn,"locs.csv",sep=""),sep=";",h=T)

# we remove the same tracks as for metabba
asbba=allserbba[!(as.character(allserbba$File)%in%removetrips),]
# we keep only encounters starting at day, containing flight during day
# we also discard, in case, any few encounters of transiting boat
asbba=asbba[asbba$dayflight==1 & asbba$daystart=="day" & abs(asbba$lagvesact)<3600,]




#### Combine trip metadata, adding info on series
for(t in 1:dim(mwa)[1]){
  trip=paste("DistOis-Bat_j-n_",as.character(mwa$File[t]),"_VitPoseCap.csv",sep="")
  
  enc=which(as.character(allserwa$File[allserwa$daystart=="day" & allserwa$dayflight==1])==trip)
  mwa$NbDaylightEncounter[t]=length(enc)
  
  
  mwa$nb_attend[t]=ifelse(length(enc)>0,sum(allserwa$dur_attend[enc]),0)
  mwa$nb_attracrange[t]=ifelse(length(enc)>0,sum(allserwa$durser[enc]),0)
}
for(t in 1:dim(mbba)[1]){
  trip=as.character(mbba$TripID[t])
  
  enc=which(as.character(allserbba$File[allserbba$daystart=="day" & allserbba$dayflight==1])==trip)
  mbba$NbDaylightEncounter[t]=length(enc)
  
  
  mbba$nb_attend[t]=ifelse(length(enc)>0,sum(allserbba$dur_attend[enc]),0)
  mbba$nb_attracrange[t]=ifelse(length(enc)>0,sum(allserbba$durser[enc]),0)
}

metaall=rbind(mwa,mbba)

write.table(metaall,file="D:/Pro/These/Donnees/WAvsBBA/MetaBBAvsWA.csv",sep=";",row.names=F)

### Combine Encounter Series
allenc=data.frame(
  "Species"=c(aswa$Species,rep("BBA",dim(asbba)[1])),
  "ReproStage"=c(as.character(aswa$ReproStage),as.character(asbba$ReproStage)),
  "Year"=c(aswa$Year,rep("2012",dim(asbba)[1])),
  "BirdID"=c(as.character(aswa$Bague),as.character(asbba$BirdID)),
  "Bague"=c(as.character(aswa$Bague),as.character(asbba$Bague)),
  "Sex"=c(as.character(aswa$Sex),as.character(asbba$Sex)),
  "TripID"=c(as.character(aswa$File),as.character(asbba$File)),
  "File"=c(as.character(aswa$File),as.character(asbba$File)),
  "Serie"=c(aswa$Serie,asbba$Serie),
  "startloc"=c(aswa$startloc,asbba$startloc),
  "startlocbat"=c(aswa$startlocbat,asbba$startlocbat),
  "startdate"=c(as.character(aswa$startdate),as.character(asbba$startdate)),
  "starttime"=c(as.character(aswa$starttime),as.character(asbba$starttime)),
  "endloc"=c(aswa$endloc,asbba$endloc),
  "endlocbat"=c(aswa$endlocbat,asbba$endlocbat),
  "durser"=c(aswa$durser,asbba$durser),
  "prop_day"=c(aswa$prop_day,asbba$prop_day),
  "dayflight"=c(aswa$dayflight,asbba$dayflight),
  "daystart"=c(as.character(aswa$daystart),as.character(asbba$daystart)),
  "vessel"=c(as.character(aswa$vessel),as.character(asbba$vessel)),
  "avg_nbbatrangedet"=c(aswa$avg_nbbatrangedet,asbba$avg_nbbatrangedet),
  "attend"=c(aswa$attend,asbba$attend),
  "dur_attend"=c(aswa$dur_attend,asbba$dur_attend),
  "prop_attend"=c(aswa$prop_attend,asbba$prop_attend),
  "avgdist_attend"=c(aswa$avgdist_attend,asbba$avgdist_attend*1000),
  "lagvesact"=c(aswa$lagvesact,asbba$lagvesact),
  "closest_vesact"=c(as.character(aswa$closestvesact),as.character(asbba$closestvesact)),
  "propact"=c(aswa$propact,asbba$propact),
  "TripDuration"=c(aswa$Duration,asbba$TripDuration),
  "TripMaxRange"=c(aswa$MaxRange,asbba$MaxRange),
  "TripNbBat"=c(aswa$avg_nbbat,asbba$avg_nbbat)
)

write.table(allenc,"D:/Pro/These/Donnees/WAvsBBA/AllDaylightEncounters_BBAvsWA_30km_3km_TTR4locs.csv",sep=";",row.names=F)







